@@ -1,6 +1,7 @@
 from pandas_profiling.report.presentation.core.alerts import Alerts
 from pandas_profiling.report.presentation.core.collapse import Collapse
 from pandas_profiling.report.presentation.core.container import Container
+from pandas_profiling.report.presentation.core.dropdown import Dropdown
 from pandas_profiling.report.presentation.core.duplicate import Duplicate
 from pandas_profiling.report.presentation.core.frequency_table import FrequencyTable
 from pandas_profiling.report.presentation.core.frequency_table_small import (
@@ -19,6 +20,7 @@ __all__ = [
     "Collapse",
     "Container",
     "Duplicate",
+    "Dropdown",
     "FrequencyTable",
     "FrequencyTableSmall",
     "HTML",
