@@ -23,6 +23,7 @@ def get_html_renderable_mapping() -> Dict[Type[Renderable], Type[Renderable]]:
         Alerts,
         Collapse,
         Container,
+        Dropdown,
         Duplicate,
         FrequencyTable,
         FrequencyTableSmall,
@@ -39,6 +40,7 @@ def get_html_renderable_mapping() -> Dict[Type[Renderable], Type[Renderable]]:
         HTMLAlerts,
         HTMLCollapse,
         HTMLContainer,
+        HTMLDropdown,
         HTMLDuplicate,
         HTMLFrequencyTable,
         HTMLFrequencyTableSmall,
@@ -63,6 +65,7 @@ def get_html_renderable_mapping() -> Dict[Type[Renderable], Type[Renderable]]:
         FrequencyTableSmall: HTMLFrequencyTableSmall,
         Alerts: HTMLAlerts,
         Duplicate: HTMLDuplicate,
+        Dropdown: HTMLDropdown,
         Sample: HTMLSample,
         ToggleButton: HTMLToggleButton,
         Collapse: HTMLCollapse,
@@ -89,6 +92,7 @@ def get_widget_renderable_mapping() -> Dict[Type[Renderable], Type[Renderable]]:
         Alerts,
         Collapse,
         Container,
+        Dropdown,
         Duplicate,
         FrequencyTable,
         FrequencyTableSmall,
@@ -104,6 +108,7 @@ def get_widget_renderable_mapping() -> Dict[Type[Renderable], Type[Renderable]]:
         WidgetAlerts,
         WidgetCollapse,
         WidgetContainer,
+        WidgetDropdown,
         WidgetDuplicate,
         WidgetFrequencyTable,
         WidgetFrequencyTableSmall,
@@ -129,6 +134,7 @@ def get_widget_renderable_mapping() -> Dict[Type[Renderable], Type[Renderable]]:
         FrequencyTableSmall: WidgetFrequencyTableSmall,
         Alerts: WidgetAlerts,
         Duplicate: WidgetDuplicate,
+        Dropdown: WidgetDropdown,
         Sample: WidgetSample,
         ToggleButton: WidgetToggleButton,
         Collapse: WidgetCollapse,
