@@ -1,6 +1,7 @@
 from pandas_profiling.report.presentation.flavours.html.alerts import HTMLAlerts
 from pandas_profiling.report.presentation.flavours.html.collapse import HTMLCollapse
 from pandas_profiling.report.presentation.flavours.html.container import HTMLContainer
+from pandas_profiling.report.presentation.flavours.html.dropdown import HTMLDropdown
 from pandas_profiling.report.presentation.flavours.html.duplicate import HTMLDuplicate
 from pandas_profiling.report.presentation.flavours.html.frequency_table import (
     HTMLFrequencyTable,
@@ -25,6 +26,7 @@ __all__ = [
     "HTMLCollapse",
     "HTMLContainer",
     "HTMLDuplicate",
+    "HTMLDropdown",
     "HTMLFrequencyTable",
     "HTMLFrequencyTableSmall",
     "HTMLHTML",
